@@ -11,6 +11,11 @@ Then /^the example(s)? should( all)? pass$/ do |_, _|
   step %q{the exit status should be 0}
 end
 
+Then /^the example(s)? should( all)? fail/ do |_, _|
+  step %q{the output should not contain "0 failures"}
+  step %q{the exit status should not be 0}
+end
+
 Given /active job is available/ do
   if !RSpec::Rails::FeatureCheck.has_active_job?
     pending "ActiveJob is not available"
