@@ -33,7 +33,8 @@ module RSpec
       :request    => %w[spec (requests|integration|api)],
       :routing    => %w[spec routing],
       :view       => %w[spec views],
-      :feature    => %w[spec features]
+      :feature    => %w[spec features],
+      :system     => %w[spec system]
     }
 
     # Sets up the different example group modules for the different spec types
@@ -48,6 +49,7 @@ module RSpec
       config.include RSpec::Rails::ViewExampleGroup,       :type => :view
       config.include RSpec::Rails::FeatureExampleGroup,    :type => :feature
       config.include RSpec::Rails::Matchers
+      config.include RSpec::Rails::SystemExampleGroup, :type => :system
     end
 
     # @private
@@ -79,6 +81,10 @@ module RSpec
         config.add_setting :file_fixture_path, :default => 'spec/fixtures/files'
         config.include RSpec::Rails::FileFixtureSupport
       end
+
+      # Add support for fixture_path on fixture_file_upload
+      config.include RSpec::Rails::FixtureFileUploadSupport
+
       # This allows us to expose `render_views` as a config option even though it
       # breaks the convention of other options by using `render_views` as a
       # command (i.e. `render_views = true`), where it would normally be used
