@@ -7,8 +7,9 @@ module RSpec
     private
 
       def rails_fixture_file_wrapper
-        resolved_fixture_path = (fixture_path || RSpec.configuration.fixture_path || '')
-        RailsFixtureFileWrapper.fixture_path = File.join(resolved_fixture_path, '')
+        RailsFixtureFileWrapper.fixture_path = nil
+        resolved_fixture_path = (fixture_path || RSpec.configuration.fixture_path || '').to_s
+        RailsFixtureFileWrapper.fixture_path = File.join(resolved_fixture_path, '') unless resolved_fixture_path.strip.empty?
         RailsFixtureFileWrapper.instance
       end
 
@@ -18,7 +19,7 @@ module RSpec
         class << self
           attr_reader :fixture_path
 
-          # Get the instance of wrapper
+          # Get instance of wrapper
           def instance
             @instance ||= new
           end
