@@ -4,13 +4,13 @@ module RSpec::Rails
   describe FixtureSupport do
     context "with use_transactional_fixtures set to false" do
       it "still supports fixture_path" do
-        RSpec.configuration.stub(:use_transactional_fixtures) { false }
+        allow(RSpec.configuration).to receive(:use_transactional_fixtures) { false }
         group = RSpec::Core::ExampleGroup.describe do
           include FixtureSupport
         end
 
-        group.should respond_to(:fixture_path)
-        group.should respond_to(:fixture_path=)
+        expect(group).to respond_to(:fixture_path)
+        expect(group).to respond_to(:fixture_path=)
       end
     end
   end
